@@ -21,13 +21,18 @@ class LanguageParser(object):
         pass
     
     @staticmethod
-    def detect_language(filename: str, runtime: str)-> Union[Python, PHP, Javascript]:
+    def detect_language(filename: str, runtime: str, is_file: bool = False, is_docker: bool = False, project_id: str = '')-> Union[Python, PHP, Javascript, Multi]:
         if runtime == 'multi':
-            return Multi(filename, runtime)
-        return LanguageParser.EXT_TO_LANG[os.path.splitext(filename)[1].lower()](filename, runtime)
+            return Multi(filename, runtime, is_docker, is_file, project_id)
+        return LanguageParser.EXT_TO_LANG[os.path.splitext(filename)[1].lower()](
+            filename, 
+            runtime, 
+            is_docker=is_docker,
+            project_id=project_id
+        )
 
     @staticmethod
     def run_file(filename, runtime):
-        lang_parser = LanguageParser.detect_language(filename, runtime)
+        lang_parser = LanguageParser.detect_language(filename, runtime, True)
         lang_parser.is_file = True
         lang_parser.anon_function()
